"""Main module."""
import sys
sys.path.append('..')
from pcaconcat import pcaconcat


